OC.L10N.register(
    "core",
    {
    "Please select a file." : "Моля изберете файл.",
    "File is too big" : "Файлът е твърде голям",
    "The selected file is not an image." : "Избраният файл не е изображение.",
    "The selected file cannot be read." : "Избраният файл не може да бъде отворен.",
    "The file was uploaded" : "Файлът е качен",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Размерът на каченият файл надвишава директивата upload_max_filesize в php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Размерът на каченият файл надвишава максималния размер, определен от MAX_FILE_SIZE в HTML формата.",
    "The file was only partially uploaded" : "Файлът е качен частично",
    "No file was uploaded" : "Няма качен файл",
    "Missing a temporary folder" : "Липсва временна папка",
    "Could not write file to disk" : " Файлът не можа да бъде записан на диск",
    "A PHP extension stopped the file upload" : "PHP разширение спря качването на файла",
    "Invalid file provided" : "Предоставен е невалиден файл",
    "No image or file provided" : "Не бяха доставени картинка или файл",
    "Unknown filetype" : "Неизвестен тип файл",
    "An error occurred. Please contact your admin." : "Възникна неизвестна грешка. Свържете с администратора.",
    "Invalid image" : "Невалидно изображение",
    "No temporary profile picture available, try again" : "Не е налична временна профилна снимка, опитайте отново",
    "No crop data provided" : "Липсват данни за изрязването",
    "No valid crop data provided" : "Данни за изрязването са невалидни",
    "Crop is not square" : "Областта не е квадратна",
    "State token does not match" : "Маркер на състояние не съвпада",
    "Invalid app password" : "Невалидна парола за приложението",
    "Could not complete login" : "Не може да завърши влизането",
    "Your login token is invalid or has expired" : "Вашият маркер за вход е невалиден или е изтекъл",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "Тази общностна версия на Nextcloud не се поддържа и push известия са ограничени.",
    "Login" : "Вписване",
    "Password reset is disabled" : "Възстановяването на пароли е забранено",
    "Could not reset password because the token is expired" : "Възстановяването на паролата е неуспешно, защото токенът е с изтекла валидност",
    "Could not reset password because the token is invalid" : "Възстановяването на паролата е неуспешно, защото токенът е невалиден",
    "%s password reset" : "%s възстановяване на парола",
    "Password reset" : "Възстановяване на парола",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Кликнете върху следния бутон, за да възстановите паролата си. Ако не сте поискали възстановяване на паролата, игнорирайте този имейл.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Кликнете върху следната връзка, за да възстановите паролата си. Ако не сте поискали възстановяване на паролата, игнорирайте този имейл.",
    "Reset your password" : "Възстановяване на вашата парола",
    "Nextcloud Server" : "Nextcloud сървър",
    "Some of your link shares have been removed" : "Някои от вашите споделяния на връзки са премахнати",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Поради грешка в сигурността трябваше да премахнем някои от вашите споделяния на връзки. Моля, вижте връзката за повече информация.",
    "The user limit of this instance is reached." : " Достигнат е потребителският лимит на този екземпляр.",
    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Въведете абонаментния си ключ, за да увеличите потребителския си лимит. За повече информация относно Nextcloud Enterprise вижте нашия уеб сайт.",
    "Preparing update" : "Подготовка за актуализиране",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Стъпка на поправка:",
    "Repair info:" : "Информация за поправка:",
    "Repair warning:" : "Предупреждение при поправка:",
    "Repair error:" : "Грешка при поправка:",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Моля използвайте съветникът за актуализиране в командния ред, защото автоматичният е забранен в config.php.",
    "Turned on maintenance mode" : "Режимът за поддръжка е включен",
    "Turned off maintenance mode" : "Режимът за поддръжка е изключен",
    "Maintenance mode is kept active" : "Режим на поддръжка се поддържа активен",
    "Updating database schema" : "Актуализиране схемата на базата данни",
    "Updated database" : "Базата данни е актуализирана",
    "Update app \"%s\" from App Store" : "Актуализиране на „%s“ от App Store",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Проверка дали схемата на базата данни %s може да бъде актуализирана (това може да отнеме повече време в зависимост от големината на базата данни)",
    "Updated \"%1$s\" to %2$s" : "Актуализиран \"%1$s\" до %2$s",
    "Set log level to debug" : "Промени ниво на лог на дебъг",
    "Reset log level" : "Възстанови ниво на лог",
    "Starting code integrity check" : "Стартиране на проверка за цялостта на кода",
    "Finished code integrity check" : "Приключена проверка за цялостта на кода",
    "%s (incompatible)" : "%s (несъвместим)",
    "The following apps have been disabled: %s" : "Следните приложения са изключени: %s",
    "Already up to date" : "Актуално",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Вашият уеб сървър все още не е удачно настроен да позволява синхронизация на файлове, защото WebDAV интерфейсът не работи.",
    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Вашият уеб сървър не е настроен правилно за разрешаване на \"{url}\". Допълнителна информация можете да намерите в {linkstart}документацията ↗{linkend}.",
    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Вашият уеб сървър не е настроен правилно за разрешаване на \"{url}\". Това най-вероятно е свързано с конфигурация на уеб сървър, която не е актуализирана, за да доставя тази папка директно. Моля, сравнете конфигурацията си с изпратените правила за пренаписване в \".htaccess\" за Apache или предоставеното в документацията за Nginx, на неговата {linkstart}странница за документация ↗{linkend}. В Nginx това обикновено са редовете, започващи с „location ~“/местоположение/, които се нуждаят от актуализация. ",
    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Вашият уеб сървър не е правилно настроен да доставя .woff2 файлове. Това обикновено е проблем с конфигурацията на Nginx. За Nextcloud 15 се нуждае от корекция, за да доставя и .woff2 файлове. Сравнете вашата конфигурация на Nginx с препоръчаната конфигурация в нашата {linkstart}документация ↗{linkend}.",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "Изглежда, че PHP не е настроен правилно за заявки за променливи на системната среда. Тестът с getenv (\"ПЪТ\") връща само празен отговор.",
    "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Моля, проверете в {linkstart}документацията за инсталиране ↗{linkend} за бележки за конфигурацията на PHP и за PHP конфигурацията на вашия сървър, особено когато използвате php-fpm.",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : " Активирана е конфигурацията само за четене. Това предотвратява настройването на някои конфигурации чрез уеб интерфейса. Освен това файлът трябва ръчно да се направи записваем за всяка актуализация.",
    "You have not set or verified your email server configuration, yet. Please head over to the {mailSettingsStart}Basic settings{mailSettingsEnd} in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "Все още не сте задали или потвърдили конфигурацията на вашия имейл сървър. Моля, отидете към {mailSettingsStart} Основни настройки {mailSettingsEnd}, за да ги зададете. След това използвайте бутон „Изпращане на имейл“ под формата, за да потвърдите настройките си.",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Вашата база данни не се изпълнява с ниво на изолация на транзакциите „АНГАЖИРАНО ЧЕТЕНЕ . Това може да създаде проблеми при паралелно изпълнение на множество действия.",
    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "PHP модулът 'fileinfo' липсва. Силно се препоръчва този модул да бъде добавен, за да се постигнат най-добри резултати при MIME тип откриване.",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the {linkstart}documentation ↗{linkend} for more information." : "Заключването на транзакционните файлове е деактивирано, това може да доведе до проблеми с условията на състезанието. Активирайте \"filelocking.enabled\" в config.php, за да избегнете тези проблеми. Вижте {linkstart}документацията ↗{linkend} за повече информация.",
    "Please make sure to set the \"overwrite.cli.url\" option in your config.php file to the URL that your users mainly use to access this Nextcloud. Suggestion: \"{suggestedOverwriteCliURL}\". Otherwise there might be problems with the URL generation via cron. (It is possible though that the suggested URL is not the URL that your users mainly use to access this Nextcloud. Best is to double check this in any case.)" : "Моля, уверете се, че сте задали опцията \"overwrite.cli.url\" във вашия файл config.php на URL адреса, който вашите потребители използват основно за достъп до този Nextcloud. Предложение: „{suggestedOverwriteCliURL}“. В противен случай може да има проблеми с генерирането на URL чрез cron. (Възможно е обаче предложеният URL да не е URL адресът, който потребителите ви използват основно за достъп до този Nextcloud. Най-добре е да проверите това отново за всеки случай.)",
    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "Вашата инсталация няма зададен регион на телефона по подразбиране. Това е нужно за проверка на телефонните номера в настройките на профила без код на държава. За да разрешите номера без код на държава, моля, добавете \"default_phone_region\" със съответния {linkstart} ISO 3166-1 код ↗ {linkend} на региона към вашия конфигурационен файл.",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Не беше възможно да се изпълни заданието cron чрез командния интерфейс CLI. Появиха се следните технически грешки:",
    "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "Изпълнението на последното фоново задание бе {relativeTime}. Изглежда нещо не е наред. {linkstart}Проверете настройките на фоновата задача ↗{linkend}.",
    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications are limited to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at {linkstart}https://nextcloud.com/enterprise{linkend}." : "Това е неподдържаната общностна версия на Nextcloud. Като се има предвид размера на този екземпляр, производителността, надеждността и мащабируемостта не могат да бъдат гарантирани. Push известия са деактивирани, за да се избегне претоварването на нашата безплатна услуга. Научете повече за предимствата на Nextcloud Enterprise на {linkstart}https://nextcloud.com/enterprise{linkend}.",
    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Сървърът няма работеща интернет връзка: Множество крайни точки не могат да бъдат достигнати. Това означава, че някои от функциите като монтиране на външно хранилище, известия за актуализации или инсталиране на приложения на трети страни няма да работят. Достъпът до файлове от разстояние и изпращането на имейли с известие, също може да не работят. Установете връзка от този сървър с Интернет, за да се насладите на всички функции.",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Не е конфигурирана кеш паметта. За да подобрите производителността, моля, конфигурирайте memcache, ако е наличен. Допълнителна информация можете да намерите в {linkstart}документацията ↗{linkend}.",
    "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Не е открит подходящ източник за случайност от PHP, което е силно обезкуражително от съображения за сигурност. Допълнителна информация можете да намерите в {linkstart}документацията ↗{linkend}.",
    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "В момента използвате PHP {версия}. Надстройте своята версия на PHP, за да се възползвате от {linkstart}актуализациите за производителност и сигурност, предоставени от PHP Group ↗{linkend}, веднага щом вашата дистрибуция я поддържа.",
    "Nextcloud 23 is the last release supporting PHP 7.3. Nextcloud 24 requires at least PHP 7.4." : "Nextcloud 23 е последното издание, поддържащо PHP 7.3. Nextcloud 24 изисква поне PHP 7.4.",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Конфигурацията на заглавката на обратния прокси сървър е неправилна или осъществявате достъп до Nextcloud от доверен прокси сървър. Ако не, това е проблем със сигурността и може да позволи на хакер да прикрие IP адреса си в Nextcloud. Допълнителна информация можете да намерите в {linkstart}документацията ↗{linkend}.",
    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the {linkstart}memcached wiki about both modules ↗{linkend}." : "Кеширането на паметта е настроено като разпределена кеш, но е инсталиран грешен PHP модул \"memcache\". \\OC\\Memcache\\Memcached поддържа само \"memcached\", но не и \"memcache\". Вижте {linkstart}memcached wiki за двата модула ↗{linkend}.",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "Някои файлове не са преминали проверката за цялост. Допълнителна информация за това как да разрешите този проблем можете да намерите в {linkstart1}документация ↗{linkend}. ({linkstart2}Списък с невалидни файлове…{linkend} / {linkstart3}Повторно сканиране…{linkend})",
    "The PHP OPcache module is not properly configured. See the {linkstart}documentation ↗{linkend} for more information." : "Модулът PHP OPcache не е конфигуриран правилно. Вижте  {linkstart}документацията ↗{linkend} за повече информация.",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "Функцията PHP \"set_time_limit\" не е налична. Това може да доведе до спиране на скриптове в средата на изпълнение, което ще повреди вашата инсталация. Активирането на тази функция е силно препоръчително.",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Вашият PHP не поддържа FreeType, в резулта това ще доведе до неправилното показване на профилните снимки и настройките на интерфейса",
    "Missing index \"{indexName}\" in table \"{tableName}\"." : "Липсва индекс „{indexName}“ в таблица „{tableName}“.",
    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Някои индекси липсват в базата данни. Не са добавени защото процеса може да отнеме доста време. Можете да стартирате процеса ръчно като изпълните командата \"occ db:add-missing-indices\". След добавянето на индексите заявките към изброените таблици ще минават много по-бързо.",
    "Missing primary key on table \"{tableName}\"." : "Липсва първичен ключ в таблица „{tableName}“.",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "В базата данни липсват някои първични ключове. Поради факта, че добавянето на първични ключове на големи маси може да отнеме известно време, те не бяха добавени автоматично. Чрез стартиране на \"occ db: add-missing-primary-keys\" тези липсващи първични ключове могат да бъдат добавени ръчно, докато екземплярът продължава да работи.",
    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "Липсва изборна колона „{columnName}“ в таблица „{tableName}“.",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "В базата данни липсват някои изборни колони. Поради факта, че добавянето на колони в големи таблици може да отнеме известно време, те не се добавят автоматично, когато могат да бъдат по избор. Чрез стартиране на \"occ db: add-missing-колони\" тези липсващи колони могат да бъдат добавени ръчно, докато екземплярът продължава да работи. След като колоните бъдат добавени, някои функции могат да подобрят отзивчивостта или използваемостта.",
    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "В този екземпляр липсват някои препоръчани PHP модули. За подобрена производителност и по-добра съвместимост е силно препоръчително да ги инсталирате.",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "PHP модулът \"imagick\" не е активиран, въпреки че приложението за теми е активирано. За да работи правилно генерирането на аватари тип favicon, трябва да инсталирате и активирате този модул.",
    "The PHP modules \"gmp\" and/or \"bcmath\" are not enabled. If you use WebAuthn passwordless authentication, these modules are required." : "PHP модулите \"gmp\" и/или \"bcmath\" не са активирани. Ако използвате удостоверяване без парола WebAuthn, тези модули са нужни.",
    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page about this ↗{linkend}." : "Изглежда, че използвате 32-битова PHP версия. Приложението Nextcloud се нуждае от 64 бита, за да работи добре. Моля, надстройте вашата операционна система и PHP до 64 бита! За повече подробности прочетете {linkstart}страницата с документация за това ↗{linkend}.",
    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "Модулът php-imagick в този случай няма поддръжка на SVG. За по-добра съвместимост се препоръчва да го инсталирате.",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "В някои колони в базата данни липсва преобразуване в big int. Поради факта, че промяната на типовете колони в големи таблици може да отнеме известно време, те не се променят автоматично. Чрез стартиране на \"occ db:convert-filecache-bigint\", тези предстоящи промени могат да бъдат приложени ръчно. Тази операция трябва да се извърши, докато екземплярът е офлайн. За повече подробности прочетете {linkstart}страницата с документация за това ↗{linkend}.",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "Понастоящем SQLite се използва като вътрешна база данни. За по-големи инсталации ви препоръчваме да превключите към друг сървър на базата данни.",
    "This is particularly recommended when using the desktop client for file synchronisation." : "Препоръчително, особено ако ползвате клиента за настолен компютър.",
    "To migrate to another database use the command line tool: \"occ db:convert-type\", or see the {linkstart}documentation ↗{linkend}." : "За да мигрирате към друга база данни, използвайте инструмент на командния ред: \"occ db:convert-type\" или вижте {linkstart}документацията ↗{linkend}.",
    "The PHP memory limit is below the recommended value of 512MB." : "Ограничението на PHP паметта е под препоръчителната стойност от 512MB.",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Някои директории на приложения се притежават от потребител, различен от този на уеб сървъра. Това може да се случи, ако приложенията са инсталирани ръчно. Проверете правата на следните директории на приложения:",
    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read {linkstart}the documentation page about this ↗{linkend}." : "MySQL се използва като база данни, но не поддържа 4-байтови символи. За да можете да обработвате 4-байтови символи (като емотикони) без проблеми в имената на файлове или коментари, например се препоръчва да активирате 4-байтовата поддръжка в MySQL. За повече подробности прочетете {linkend}страницата с документация за това↗{linkend}.",
    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "Този екземпляр използва базирано на S3 хранилище на обекти като основно съхранение. Качените файлове се съхраняват временно на сървъра и затова се препоръчва да имате 50 GB свободно място във временната директория на PHP. Проверете дневниците за пълни подробности за пътя и наличното пространство. За да подобрите това, моля, променете временната директория в php.ini или направете повече място в този път.",
    "The temporary directory of this instance points to an either non-existing or non-writable directory." : "Временната директория на този екземпляр сочи към несъществуваща директория или такава, която не може да се записва.",
    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "Вие имате достъп до вашия екземпляр през защитена връзка, но вашият екземпляр генерира несигурни URL адреси. Това най-вероятно означава, че сте зад обратен прокси и конфигурационните променливи за презаписване не са зададени правилно. Моля, прочетете {linkstart}страницата с документация за това ↗{linkend}.",
    "Error occurred while checking server setup" : "Възникна грешка при проверката на настройките на сървъра",
    "For more details see the {linkstart}documentation ↗{linkend}." : "За повече подробности вижте {linkstart}документацията ↗{linkend}.",
    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Вероятно вашите данни и файлове са достъпни от интернет. .htaccess файлът не функционира. Силно се препоръчва да настроите уеб сървъра по такъв начин, че директорията за данни да не бъде достъпна или я преместете извън началната директория на уеб сървъра.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP заглавката „{header}“ не е зададена на „{expected}“. Това е потенциален риск за сигурността или поверителността, като се препоръчва да настроите по подходящ начин тази настройка.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "HTTP заглавката „{header}“ не е зададена на „{expected}“. Някои функции може да не работят правилно, тъй като се препоръчва да настроите по подходящ начин тази настройка.",
    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP заглавката „{header}“ не съдържа „{expected}“. Това е потенциален риск за сигурността или поверителността, като се препоръчва да настроитепо подходящ начин тази настройка.",
    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "HTTP заглавката \"{header}\" не е зададена на \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" или \"{val5}\". Това може да доведе до изтичане на референтна информация. Вижте {linkstart}препоръката на W3C ↗{linkend}.",
    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "HTTP заглавката \"Strict-Transport-Security\" не е настроена на поне \"{seconds}\" секунди. За подобрена сигурност се препоръчва да активирате HSTS, както е описано в {linkstart}съветите за сигурност ↗{linkend}.",
    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}." : "Достъпът до сайта е несигурен чрез HTTP. Силно ви препоръчваме да настроите сървъра си да изисква HTTPS вместо това, както е описано в {linkstart}съветите за сигурност ↗{linkend}. ",
    "unknown text" : "непознат текст",
    "Hello world!" : "Здравей Свят!",
    "sunny" : "слънчево",
    "Hello {name}, the weather is {weather}" : "Здравейте {name}, времето е {weather}",
    "Hello {name}" : "Здравейте, {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Това са вашите резултати от търсенето<script>сигнал (1)</script></strong>",
    "new" : "нов",
    "_download %n file_::_download %n files_" : ["изтегли %n файл","изтегли %n файла"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "Актуализирането е в процес, в някой среди - напускането на тази страница може да прекъсне процеса.",
    "Update to {version}" : "Актуализирай до {version}",
    "An error occurred." : "Възникна грешка.",
    "Please reload the page." : "Моля, презаредете страницата.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Актуализацията беше неуспешна. За допълнителна информация <a href=\"{url}\">прегледайте темата</a> относно този проблем.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Актуализирането беше неуспешно. Моля отнесете този проблем към <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\"> Nextcloud общността</a>.",
    "Continue to {productName}" : "Продължаване към {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Актуализацията беше успешна. Пренасочване към {productName} след %n секунди.","Актуализацията беше успешна. Пренасочване към {productName} след %n секунди."],
    "More apps" : "Още приложения",
    "Currently open" : "В момента са отворени",
    "_{count} notification_::_{count} notifications_" : ["{count} известие","{count} известия"],
    "Log in" : "Вписване",
    "Logging in …" : "Вписване ...",
    "Server side authentication failed!" : "Неуспешно удостоверяването от страна на сървъра!",
    "Please contact your administrator." : "Моля, свържете се с администратора.",
    "An internal error occurred." : "Възникна вътрешно сървърна грешка.",
    "Please try again or contact your administrator." : "Опитайте отново или се свържете с администраотра.",
    "Account name or email" : "Име на профил или имейл",
    "Password" : "Парола",
    "Wrong username or password." : "Грешен потребител или парола",
    "User disabled" : "Потребителят е деактивиран",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Открихме множество невалидни опити за влизане от вашия IP. Следователно следващото ви влизане се ограничава за 30 секунди.",
    "Username or email" : "Потребител или имейл",
    "Your account is not setup for passwordless login." : "Вашият профил не е настроен за влизане без парола.",
    "Browser not supported" : "Браузърът не се поддържа",
    "Passwordless authentication is not supported in your browser." : "Удостоверяването без парола не се поддържа във вашия браузър.",
    "Your connection is not secure" : "Връзката ви не е сигурна",
    "Passwordless authentication is only available over a secure connection." : "Удостоверяването без парола е достъпно само чрез защитена връзка.",
    "Reset password" : "Възстановяване на паролата",
    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "На имейл адреса на този профил е изпратено съобщение за нулиране на парола. Ако не го получите, проверете папките си за нежелана поща / отпадъци или попитайте вашият местен администратор за помощ.",
    "If it is not there ask your local administrator." : "Ако не е там, попитайте местния администратор.",
    "Couldn't send reset email. Please contact your administrator." : "Неуспешно изпращане на имейл за възстановяване на паролата. Моля, свържете се с вашия администратор.",
    "Password cannot be changed. Please contact your administrator." : "Паролата не може да бъде променена. Моля, свържете се с вашия администратор.",
    "Back to login" : "Обратно към вписване",
    "New password" : "Нова парола",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Вашите файлове са криптирани. След като паролата ви бъде нулирана, няма да можете да си върнете данните. Ако не сте сигурни какво да правите, моля, свържете се с вашия администратор, преди да продължите. Наистина ли искате да продължите?",
    "I know what I'm doing" : "Знам какво правя",
    "Resetting password" : "Възстановяване на паролата",
    "Recommended apps" : "Препоръчани приложения",
    "Loading apps …" : "Зареждане на приложения ...",
    "Could not fetch list of apps from the App Store." : "Списъкът с приложения не можа да се извлече от App Store.",
    "Installing apps …" : "Инсталиране на приложения ...",
    "App download or installation failed" : "Изтеглянето или инсталирането на приложението беше неуспешно",
    "Cannot install this app because it is not compatible" : "Това приложение не може да се инсталира, защото е несъвместимо",
    "Cannot install this app" : "Това приложение не може да се инсталира",
    "Skip" : "Пропускане",
    "Install recommended apps" : "Инсталиране на препоръчаните приложения ",
    "Schedule work & meetings, synced with all your devices." : "Планирайте работа и срещи, синхронизирано с всичките ви устройства.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Бъдете с колегите и приятелите си на едно място, без да изтича тяхната лична информация.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Опростено приложение за електронна поща, добре интегрирано с файлове, контакти и календар.",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Чат, видео разговори, споделяне на екрана, онлайн срещи и уеб конферентни връзки - във вашия браузър и с мобилни приложения.",
    "Collaboratively edit office documents." : "Съвместно редактиране на офис документи.",
    "Local document editing back-end used by the Collabora Online app." : "Местно фоново редактиране на документи, чрез използване на приложението Collabora Online.",
    "Forgot password?" : "Забравена парола?",
    "Log in with a device" : "Вписване с устройство",
    "Back" : "Назад",
    "Login form is disabled." : "Формулярът за вход е деактивиран",
    "Edit Profile" : "Редактиране на профил",
    "The headline and about sections will show up here" : "Заглавието и секцията за информация ще се покажат тук",
    "You have not added any info yet" : "Все още не сте добавили никаква информация",
    "{user} has not added any info yet" : "{user} все още не е добавил никаква информация",
    "Error opening the user status modal, try hard refreshing the page" : "Грешка при отваряне на модалния статус на потребителя, опитайте настоятелно да опресните страницата",
    "Search starts once you start typing" : "Търсенето започва, щом започнете да пишете",
    "Reset search" : "Рестартирай търсенето",
    "Start search" : "Начало на търсене",
    "Search for {name} only" : "Търсене само за {name}",
    "No results for {query}" : "Няма резултати за {query}",
    "Press enter to start searching" : "Натиснете въведи, за начало на търсенето",
    "Start typing to search" : "Започнете да пишете, за търсене",
    "Loading more results …" : "Зарежда още резултати…",
    "Load more results" : "Зареждане на още резултати",
    "Search" : "Търсене",
    "An error occurred while searching for {type}" : "Възникна грешка при търсенето на {type}",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Моля, въведете {minSearchLength} знака или повече, за да търсите","Моля, въведете {minSearchLength} знака или повече, за да търсите"],
    "Search {types} …" : "Търсене на  {types}  ...",
    "Settings" : "Настройки",
    "Could not load your contacts" : "Контактите не могат да бъдат заредени",
    "Search contacts …" : "Търсене в контактите ...",
    "No contacts found" : "Няма намерени контакти",
    "Show all contacts …" : "Покажи всички контакти ...",
    "Install the Contacts app" : "Инсталиране на приложението за Контакти ",
    "Loading your contacts …" : "Зареждане на контактите ...",
    "Looking for {term} …" : "Търси се {term} …",
    "No" : "Не",
    "Yes" : "Да",
    "No files in here" : "Няма файлове",
    "New folder" : "Нова папка",
    "No more subfolders in here" : "Няма подпапки",
    "Name" : "Име",
    "Size" : "Размер",
    "Modified" : "Промяна",
    "\"{name}\" is an invalid file name." : "\"{name}\" е непозволено име за файл.",
    "File name cannot be empty." : "Името на файла не може да бъде празно.",
    "\"/\" is not allowed inside a file name." : "\"/\" е непозволен знак в името на файла.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" не е разрешен тип файл",
    "{newName} already exists" : "{newName} вече съществува",
    "Choose" : "Избор",
    "Copy" : "Копирай",
    "Move" : "Премести",
    "Error loading file picker template: {error}" : "Грешка при зареждането на шаблона за избор на файл: {error}",
    "OK" : "Добре",
    "Error loading message template: {error}" : "Грешка при зареждането на шаблона за съобщения: {error}",
    "read-only" : "Само за четене",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} файлов конфликт","{count} файлови кофликта"],
    "One file conflict" : "Един файлов конфликт",
    "New Files" : "Нови файлове",
    "Already existing files" : "Вече съществуващи файлове",
    "Which files do you want to keep?" : "Кои файлове желете да запазите?",
    "If you select both versions, the copied file will have a number added to its name." : "Ако изберете и двете версии, към името на копирания файл ще бъде добавено число.",
    "Cancel" : "Отказ",
    "Continue" : "Продължаване",
    "(all selected)" : "(всички избрани)",
    "({count} selected)" : "({count} избрани)",
    "Error loading file exists template" : "Грешка при зареждането на шаблона за вече съществуващ файл",
    "Show list view" : "Показване с изглед на списък",
    "Show grid view" : "Показване в решетъчен изглед",
    "Pending" : "Чакащо",
    "Copy to {folder}" : "Копирай в {folder}",
    "Move to {folder}" : "Премести в {folder}",
    "Saving …" : "Записване …",
    "Authentication required" : "Изисква удостоверяване",
    "This action requires you to confirm your password" : "Необходимо е да потвърдите паролата си",
    "Confirm" : "Потвърди",
    "Failed to authenticate, try again" : "Грешка при удостоверяване, опитайте пак",
    "seconds ago" : "преди секунди",
    "Connection to server lost" : "Няма връзка със сървъра",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Проблем при зареждането на страницата, презареждане след %n секунда","Проблем при зареждането на страницата, презареждане след %n секунди"],
    "Add to a project" : "Добавяне към проект",
    "Show details" : "Показване на подробности",
    "Hide details" : "Скриване на подробностите",
    "Rename project" : "Преименуване на проект",
    "Failed to rename the project" : "Неуспешно преименуване на проект",
    "Failed to create a project" : "Неуспешно създаване на проект",
    "Failed to add the item to the project" : "Неуспешно добавяне на елемент към проекта",
    "Connect items to a project to make them easier to find" : "Свързване на елементи към проект, за да станат лесни за намиране",
    "Type to search for existing projects" : "Въведете, за търсене на съществуващи проекти",
    "New in" : "Ново в",
    "View changelog" : "Преглед на списъка с промени",
    "Very weak password" : "Много проста парола",
    "Weak password" : "Проста парола",
    "So-so password" : "Не особено добра парола",
    "Good password" : "Добра парола",
    "Strong password" : "Сложна парола",
    "No action available" : "Няма налични действия",
    "Error fetching contact actions" : "Грешка при извличането на действия за контакт",
    "Non-existing tag #{tag}" : "Несъществуващ етикет #{tag}",
    "restricted" : "ограничен",
    "invisible" : "невидим",
    "Delete" : "Изтрий",
    "Rename" : "Преименувай",
    "Collaborative tags" : "Съвместни етикети",
    "No tags found" : "Не са открити етикети",
    "Personal" : "Лични",
    "Users" : "Потребители",
    "Apps" : "Приложения",
    "Admin" : "Админ",
    "Help" : "Помощ",
    "Access forbidden" : "Достъпът е забранен",
    "Profile not found" : "Профилът не е намерен",
    "The profile does not exist." : "Профилът не съществува.",
    "Back to %s" : "Обратно към %s",
    "File not found" : "Файлът не е открит",
    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Документът не можа да бъде намерен на сървъра. Може би споделянето е изтрито или е изтекло?",
    "Too many requests" : "Твърде много заявки",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Имаше твърде много заявки от вашата мрежа. Опитайте отново по-късно или се свържете с вашия администратор, ако това е грешка.",
    "Error" : "Грешка",
    "Previous" : "Предишен ",
    "Internal Server Error" : "Вътрешно сървърна грешка",
    "The server was unable to complete your request." : "Сървърът не можа да изпълни заявката ви.",
    "If this happens again, please send the technical details below to the server administrator." : "Ако грешката се повтори, моля изпратете техническите данни на администратора.",
    "More details can be found in the server log." : "Подробности можете да намерите в журнала на сървъра.",
    "Technical details" : "Технически данни",
    "Remote Address: %s" : "Отдалечен адрес: %s",
    "Request ID: %s" : "ID на заявката: %s",
    "Type: %s" : "Тип: %s",
    "Code: %s" : "Код: %s",
    "Message: %s" : "Съобщение: %s",
    "File: %s" : "Файл: %s",
    "Line: %s" : "Ред: %s",
    "Trace" : "Проследяване на грешките",
    "Security warning" : "Предупреждение за сигурност",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Директория с данни и файлове ви са вероятно са достъпни от Интернет, защото файлът \".htaccess\" не функционира.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Информация, как да настроите сървъра коректно, ще намерите в <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">документацията</a>.",
    "Create an <strong>admin account</strong>" : "Създаване на <strong>администраторски профил</strong>.",
    "Username" : "Потребител",
    "Show password" : "Покажи парола",
    "Toggle password visibility" : "Превключване на видимостта на парола",
    "Storage & database" : "Хранилища и бази данни",
    "Data folder" : "Директория за данни",
    "Configure the database" : "Конфигуриране на базата данни",
    "Only %s is available." : "Само %s е наличен.",
    "Install and activate additional PHP modules to choose other database types." : "Инсталирайте и активирайте допълнителни PHP модули, за да изберете други видове бази данни.",
    "For more details check out the documentation." : "За повече информация проверете документацията.",
    "Database user" : "Потребител за базата данни",
    "Database password" : "Парола за базата данни",
    "Database name" : "Име на базата данни",
    "Database tablespace" : "Tablespace на базата данни",
    "Database host" : "Хост",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Моля, посочете номера на порта заедно с името на хоста (напр. Localhost: 5432).",
    "Performance warning" : "Предупреждение за производителността",
    "You chose SQLite as database." : "Избрахте база данни SQLite.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite трябва да се използва само за минимални екземпляри и екземпляри за разработка. За производство препоръчваме различен сървър на базата данни.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Ако използвате клиенти за синхронизиране на файлове, използването на SQLite не се препоръчва.",
    "Install" : "Инсталиране",
    "Installing …" : "В процес на инсталиране…",
    "Need help?" : "Нуждаете се от помощ?",
    "See the documentation" : "Прегледайте документацията",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Изглежда, че се опитвате да преинсталирате Nextcloud. Файлът CAN_INSTALL обаче липсва във вашата конфигурационна директория. Моля, създайте файла CAN_INSTALL във вашата конфигурационна папка, за да продължите.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "CAN_INSTALL не можа да се премахне от конфигурационната папка. Моля, премахнете този файл ръчно.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Приложението изисква JavaScript. Моля, {linkstart}включете JavaScript{linkend} и презаредете страницата.",
    "Skip to main content" : "Преминаване към основното съдържание",
    "Skip to navigation of app" : "Преминаване към навигация на приложението",
    "Get your own free account" : "Вземете свой собствен безплатен профил",
    "%s's homepage" : "%s's начална страница",
    "Contacts" : "Контакти",
    "Contacts menu" : "Контакти",
    "Open settings menu" : "Отваряне на меню за настройки",
    "Confirm your password" : "Потвърдете паролата си",
    "Connect to your account" : "Свързване към вашия профил",
    "Please log in before granting %1$s access to your %2$s account." : "Необходимо е да се впишете, преди да дадете достъп на %1$s до вашия %2$s профил.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Ако не се опитвате да настроите ново устройство или приложение, някой се опитва да ви подмами, за да му предоставите достъп до вашите данни. В този случай не продължавайте и вместо това се свържете със системния си администратор.",
    "App token" : "Парола за приложението",
    "Grant access" : "Разреши достъпa",
    "Alternative log in using app token" : "Алтернативен метод за вписване с парола за приложение",
    "Account access" : "Достъп до профил",
    "Currently logged in as %1$s (%2$s)." : "В момента сте влезли като %1$s (%2$s).",
    "You are about to grant %1$s access to your %2$s account." : "Ще разрешите на %1$s да ползва вашия %2$s профил.",
    "Account connected" : "Профилът е свързан",
    "Your client should now be connected!" : "Клиентът ви вече трябва да е свързан!",
    "You can close this window." : "Можеш да затвориш този прозорец.",
    "This share is password-protected" : "Тази зона е защитена с парола.",
    "The password is wrong or expired. Please try again or request a new one." : "Паролата е грешна или е изтекла. Моля, опитайте отново или поискайте нова.",
    "Please type in your email address to request a temporary password" : "Моля, въведете имейл адреса си, за да поискате временна парола",
    "Email address" : "Имейл адрес",
    "Password sent!" : "Паролата е изпратена!",
    "You are not authorized to request a password for this share" : "Не сте упълномощени да искате парола за това споделяне",
    "Go to %s" : "Отидете на %s",
    "Two-factor authentication" : "Двустепенно удостоверяване",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Повишената сигурност е активирана за вашия профил. Изберете втори фактор за удостоверяване .",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Невъзможно да се зареди поне един от вашите активирани двустепенни методи за удостоверяване. Моля, свържете се с вашия администратор.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Двустепенното удостоверяване е приложено, но не е конфигурирано във вашия профил. Свържете се с вашия администратор за съдействие.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Двустепенното удостоверяване е приложено, но не е конфигурирано във вашия профил. Свържете се с вашия администратор за съдействие.",
    "Set up two-factor authentication" : "Двустепенно удостоверяване",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Двустепенното удостоверяване е приложено, но не е конфигурирано във вашия профил. Използвайте един от резервните си кодове, за да влезете или се свържете с вашия администратор за съдействие.",
    "Use backup code" : "Използвай код за възстановяване",
    "Cancel login" : "Откажи вписване",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Повишената сигурност е активирана за вашия профил. Изберете кой доставчик да настроите: ",
    "Error while validating your second factor" : "Грешка при валидиране на втория ви фактор",
    "Access through untrusted domain" : "Достъп през недоверен домейн",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Моля, свържете се с администратора. Ако сте администратор на текущата инстанция, конфигурирайте \"trusted_domains\" настройките в config/config.php. Примерна конфигурация е предоставена в config/config.sample.php.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Допълнителна информация как да конфигурирате това можете да намерите в %1$sдокументацията%2$s.",
    "App update required" : "Изисква се актуализиране на приложението",
    "%1$s will be updated to version %2$s" : "%1$s ще бъде актуализирана до версия %2$s",
    "The following apps will be updated:" : "Следните приложения ще бъдат актуализирани:",
    "These incompatible apps will be disabled:" : "Следните несъвместими добавки ще бъдат деактивирани:",
    "The theme %s has been disabled." : "Темата %s е изключена.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Моля, уверете се, че сте направили копия на базата данни, папките с настройки и данните, преди да продължите.",
    "Start update" : "Начало на обновяването",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "За да избегнеш таймаутове при по-големи инсталации, можеш да изпълниш следните команди в инсталанционната директория:",
    "Detailed logs" : "Подробни журнали",
    "Update needed" : "Нужно е актуализиране",
    "Please use the command line updater because you have a big instance with more than 50 users." : "Моля, използвайте актуализатора на командния ред, защото имате голям екземпляр с повече от 50 потребители.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "За помощ, прегледайте <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">документацията</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Знам, че ако продължа да правя актуализацията чрез уеб потребителски интерфейсUI , има риск заявката временно да се прекъсне и може да доведе до загуба на данни, но имам резервно копие и знам как да възстановя своя екземпляр в случай на повреда.",
    "Upgrade via web on my own risk" : "Актуализиране чрез интернет на собствен риск",
    "Maintenance mode" : "Режим на поддръжка",
    "This %s instance is currently in maintenance mode, which may take a while." : "В момента се извършва профилактика на %s, може да продължи дълго.",
    "This page will refresh itself when the instance is available again." : "Страницата ще се зареди автоматично, когато е отново на линия.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Свържете се със системния администратор ако това съобщение се задържи твърде дълго или се е появило неочаквано.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: Проверяване на таблица %s",
    "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "Сървърът няма работеща интернет връзка: Множество крайни точки не могат да бъдат достигнати. Това означава, че някои от функциите като монтиране на външно хранилище, известия за актуализации или инсталиране на приложения на трети страни няма да работят. Достъпът до файлове от разстояние и изпращането на имейли с известия също може да не работят. Установете връзка от този сървър с Интернет, за да се насладите на всички функции.",
    "Nextcloud 20 is the last release supporting PHP 7.2. Nextcloud 21 requires at least PHP 7.3." : "Nextcloud 20 е последното издание, поддържащо PHP 7.2. Nextcloud 21 изисква поне PHP 7.3.",
    "The PHP OPcache module is not loaded. {linkstart}For better performance it is recommended ↗{linkend} to load it into your PHP installation." : "Модулът PHca OPcache не е зареден. {linkstart}За по-добра производителност се препоръчва ↗{linkend} да го заредите във вашата PHP инсталация.",
    "The PHP OPcache module is not properly configured. {linkstart}For better performance it is recommended ↗{linkend} to use the following settings in the <code>php.ini</code>:" : "Модулът PHca OPcache не е зареден. {linkstart}За по-добра производителност се препоръчва ↗{linkend} да използвате следните настройки в <code>PHP инсталация</code>:",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running 'occ db:convert-filecache-bigint' those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "В някои колони от базата данни липсва преобразуване в big int. Поради факта, че промяната на типовете колони в големи таблици може да отнеме известно време, те не се променят автоматично. Чрез стартиране на 'occ db:convert-filecache-bigint' тези чакащи промени могат да бъдат приложени ръчно. Тази операция трябва да се извърши, докато екземплярът е офлайн. За повече подробности прочетете {linkstart}страницата с документация за това ↗{linkend}. ",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the {linkstart}documentation ↗{linkend}." : "За да мигрирате към друга база данни, използвайте инструмента за команден ред: 'occ db: convert-type' или вижте  {linkstart}документацията ↗{linkend}.",
    "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Най-вероятно вашите данни и файлове са достъпни от интернет. .htaccess файлът не функционира. Силно се препоръчва да настроите уеб сървъра по такъв начин, че директорията за данни да не бъде достъпна или я преместете извън началната директория на уеб сървъра.",
    "More" : "Още",
    "More apps menu" : "Още от меню за приложения",
    "Settings menu" : "Настройки",
    "The password is wrong. Try again." : "Паролата е грешна. Опитайте отново.",
    "Setup two-factor authentication" : "Свържи двустепенно удостоверяване",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Тази общностна версия на Nextcloud не се поддържа и незабавните известия не са налични.",
    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications have been disabled to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at nextcloud.com/enterprise." : "Това е неподдържаната общностна версия на Nextcloud. Като се има предвид размера на този екземпляр, производителността, надеждността и мащабируемостта не могат да бъдат гарантирани. Push известията са деактивирани, за да се избегне претоварването на нашата безплатна услуга. Научете повече за предимствата на Nextcloud Enterprise на nextcloud.com/enterprise.",
    "You haven't added any info yet" : "Все още не сте добавили никаква информация",
    "{user} hasn't added any info yet" : "{user} все още не е добавил никаква информация"
},
"nplurals=2; plural=(n != 1);");
